Summary:     A transparent FTP proxy
Name:        frox
Version:     0.7.18
Release:     6.pp
License:     GPL
Group:       System Environment/Daemons
Source0:     http://%{name}.sourceforge.net/download/%{name}-%{version}.tar.bz2
Source1:     %{name}.init
Source2:     %{name}.logrotate
Patch0:      %{name}-config.patch
URL:         http://%{name}.sourceforge.net
Buildroot:   /var/tmp/%{name}-root
Vendor:      James Hollingshead <frox@hollo.org>
Packager:    Peter Pramberger <peter.pramberger@member.fsf.org>
Provides:    %{name}.pp
Requires:    glibc openssl097
Prereq:      /bin/bash
BuildPrereq: gcc >= 2.96 /bin/mkdir /usr/bin/make /usr/bin/install
BuildPrereq: glibc-devel perl openssl097-devel
ExclusiveOS: linux


%description
Frox is a transparent FTP proxy that runs under Linux and *BSD.
It should also work on other UNIX OSes that use ipfilter. It
supports caching of FTP downloads, either by redirecting through
a Squid proxy, or through its own local cache. Downloads may
also be transparently scanned for viruses (through an external
scanner). Additionally there is an interface for writing scripts
to add features or modify frox's behavior, and examples are
included to limit download file size and to transparently direct
connections to specific hosts to mirror servers. The proxy is
written with security in mind, and in the default setup runs as
a non-root user in a chroot jail.


%prep
%setup -q
%patch0 -p1
cp -f doc/ccp-sizelimit-example.sh ccp-sizelimit-example
cd src; ./configen.pl configs.tpl configs.c.in configs.c


%build
export CFLAGS="$RPM_OPT_FLAGS -I/usr/kerberos/include"
./configure \
	--prefix=/usr             \
	--sysconfdir=/etc         \
	--localstatedir=/var      \
	--mandir=/usr/share/man   \
	--enable-ipfilter         \
	--enable-http-cache       \
	--enable-local-cache      \
	--enable-virus-scan       \
	--enable-ssl              \
	--enable-transparent-data \
	--enable-libiptc          \
	--enable-ccp              \
	--enable-procname         \
	--enable-configfile=/etc/frox.conf
make all
gcc -o ccp-mirrors-example doc/ccp-mirrors-example.c


%define __os_install_post /usr/lib/rpm/brp-compress


%install
rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT/etc/rc.d/init.d
mkdir -p $RPM_BUILD_ROOT/etc/logrotate.d
mkdir -p $RPM_BUILD_ROOT/usr/libexec/frox
mkdir -p $RPM_BUILD_ROOT/usr/share/man/{man5,man8}
mkdir -p $RPM_BUILD_ROOT/var/{lib,log,run}/frox
make DESTDIR=$RPM_BUILD_ROOT install
install -m 0644 src/frox.conf $RPM_BUILD_ROOT/etc/frox.conf
cp -f $RPM_BUILD_ROOT/etc/frox.conf $RPM_BUILD_ROOT/etc/frox.conf.default
install -m 0755 %{SOURCE1} $RPM_BUILD_ROOT/etc/rc.d/init.d/frox
install -m 0644 %{SOURCE2} $RPM_BUILD_ROOT/etc/logrotate.d/frox
install -m 0644 doc/frox.conf.man $RPM_BUILD_ROOT/usr/share/man/man5/frox.conf.5
install -m 0644 doc/frox.man $RPM_BUILD_ROOT/usr/share/man/man8/frox.8
install -m 0700 ccp-* $RPM_BUILD_ROOT/usr/libexec/frox


%pre
if ! grep frox /etc/group > /dev/null 2>&1; then
   /usr/sbin/groupadd frox > /dev/null 2>&1
fi
if ! grep frox /etc/passwd > /dev/null 2>&1; then
   /usr/sbin/useradd -g frox -G frox -d /var/lib/frox \
      -r -s /dev/null frox > /dev/null 2>&1
fi


%post
/sbin/chkconfig --add frox
if [ -f /var/lock/subsys/frox ]; then
   /etc/rc.d/init.d/frox restart
fi


%preun
if [ $1 = 0 ]; then
   /sbin/chkconfig frox off
   /sbin/chkconfig --del frox
   if [ -f /var/lock/subsys/frox ]; then
      /etc/rc.d/init.d/frox stop
   fi
fi


%clean
rm -rf ${RPM_BUILD_ROOT}


%files
%defattr(-,root,root)
%doc BUGS COPYING README
%doc doc/ChangeLog doc/CREDITS doc/FAQ* doc/IN* doc/RE* doc/SEC* doc/TODO
%config(noreplace) %attr(640,root,frox) /etc/frox.conf
/etc/frox.conf.default
%config(noreplace) /etc/logrotate.d/*
/etc/rc.d/init.d/*
%dir /usr/libexec/frox
/usr/libexec/frox/*
/usr/sbin/*
/usr/share/man/man5/*
/usr/share/man/man8/*
%dir %attr(750,frox,frox) /var/lib/frox
%dir %attr(750,frox,frox) /var/log/frox
%dir %attr(750,frox,frox) /var/run/frox


%changelog
* Mon May 30 2005 peter.pramberger@member.fsf.org
- new version 0.7.18

* Wed Sep 22 2004 peter.pramberger@member.fsf.org
- added patch to allow FTPProxy in SubSection's too

* Wed Aug 18 2004 peter.pramberger@member.fsf.org
- new version 0.7.15
- added patch for proxy->client active ftp data source ip

* Mon May 10 2004 peter.pramberger@member.fsf.org
- created

